export const GET_MOVIE_BY_ID = `
GRAPH movieGraph
MATCH (m:Movies { id: @movieId })
OPTIONAL MATCH (director:People)-[:Directed]->(m)
OPTIONAL MATCH (actor:People)-[:ActedIn]->(m)
OPTIONAL MATCH (genre:Genres)-[:HasGenre]->(m)
RETURN
  m.id AS movieId,
  m.title AS title,
  m.description AS description,
  m.year AS year,
  m.runtime AS runtime,
  m.votes AS votes,
  director.id AS directorId,
  director.name AS directorName,
  actor.id AS actorId,
  actor.name AS actorName,
  genre.id AS genreId,
  genre.name AS genreName
`;

export const GET_MOVIE_BY_TITLE = `
GRAPH movieGraph
MATCH (m:Movies { title: @title })
OPTIONAL MATCH (director:People)-[directed:Directed]->(m)
OPTIONAL MATCH (actor:People)-[acted:ActedIn]->(m)
OPTIONAL MATCH (genre:Genres)-[hasGenre:HasGenre]->(m)
RETURN
  m.id AS movieId,
  m.title AS movieTitle,
  m.description AS movieDescription,
  m.year AS movieYear,
  m.runtime AS movieRuntime,
  m.votes AS movieVotes,
  director.id AS directorId,
  director.name AS directorName,
  actor.id AS actorId,
  actor.name AS actorName,
  genre.id AS genreId,
  genre.name AS genreName,
  directed.id AS directedId,
  acted.id AS actedInId,
  hasGenre.id AS hasGenreId
ORDER BY m.year DESC
`;

export const GET_MOVIES_BY_DIRECTOR_NAME = `
  GRAPH movieGraph
  MATCH (director:People {name: @directorName})-[directed:Directed]->(movie:Movies)
  RETURN
    director.id AS directorId,
    director.name AS directorName,
    directed.id AS directedId,
    movie.id AS movieId,
    movie.title AS movieTitle,
    movie.year AS movieYear,
    movie.runtime AS movieRuntime,
    movie.votes AS movieVotes,
    movie.description AS movieDescription
  ORDER BY movie.year DESC
  `;

export const GET_MOVIES_BY_GENRE_NAME = `
  GRAPH movieGraph
  MATCH (genre:Genres {name: @genreName})-[hasGenre:HasGenre]->(movie:Movies)
  RETURN
    genre.id AS genreId,
    genre.name AS genreName,
    hasGenre.id AS hasGenreId,
    movie.id AS movieId,
    movie.title AS movieTitle,
    movie.year AS movieYear,
    movie.runtime AS movieRuntime,
    movie.votes AS movieVotes,
    movie.description AS movieDescription
  ORDER BY movie.year DESC
  `;

export const GET_MOVIES_BY_ACTOR_NAME = `
GRAPH movieGraph
  MATCH (actor:People {name: @actorName})-[actedIn:ActedIn]->(movie:Movies)
  OPTIONAL MATCH (director:People)-[directed:Directed]->(movie:Movies)
  RETURN
    actor.id AS actorId,
    actor.name AS actorName,
    actedIn.id AS actedInId,
    movie.id AS movieId,
    movie.title AS movieTitle,
    movie.year AS movieYear,
    movie.runtime AS movieRuntime,
    movie.votes AS movieVotes,
    movie.description AS movieDescription,
    director.id AS directorId,
    director.name AS directorName,
    directed.id AS directedId
  ORDER BY movie.year DESC
  `;
