export const dbSchema = [
  // Movies table (Node)
  `CREATE TABLE Movies (
        id STRING(36) NOT NULL,
        title STRING(MAX) NOT NULL,
        description STRING(MAX),
        year INT64,
        runtime INT64,
        votes INT64,
      ) PRIMARY KEY (id)`,

  // People table (Node)
  `CREATE TABLE People (
        id STRING(36) NOT NULL,
        name STRING(MAX) NOT NULL
      ) PRIMARY KEY (id)`,

  // Genres table (Node)
  `CREATE TABLE Genres (
        id STRING(36) NOT NULL,
        name STRING(MAX) NOT NULL
      ) PRIMARY KEY (id)`,

  // Directed relationship table (Edge)
  `CREATE TABLE Directed (
        id STRING(36) NOT NULL,
        personId STRING(36) NOT NULL,
        movieId STRING(36) NOT NULL,
        FOREIGN KEY (personId) REFERENCES People (id),
        FOREIGN KEY (movieId) REFERENCES Movies (id)
      ) PRIMARY KEY (id)`,

  // ActedIn relationship table (Edge)
  `CREATE TABLE ActedIn (
        id STRING(36) NOT NULL,
        personId STRING(36) NOT NULL,
        movieId STRING(36) NOT NULL,
        FOREIGN KEY (personId) REFERENCES People (id),
        FOREIGN KEY (movieId) REFERENCES Movies (id)
      ) PRIMARY KEY (id)`,

  // HasGenre relationship table (Edge)
  `CREATE TABLE HasGenre (
        id STRING(36) NOT NULL,
        movieId STRING(36) NOT NULL,
        genreId STRING(36) NOT NULL,
        FOREIGN KEY (movieId) REFERENCES Movies (id),
        FOREIGN KEY (genreId) REFERENCES Genres (id)
      ) PRIMARY KEY (id)`,

  // Optional - Create indexes for faster graph traversal
  `CREATE INDEX MoviesByTitle ON Movies (title)`,
  `CREATE INDEX PeopleByName ON People (name)`,
  `CREATE INDEX GenresByName ON Genres (name)`,
  `CREATE INDEX DirectedByPerson ON Directed (personId)`,
  `CREATE INDEX DirectedByMovie ON Directed (movieId)`,
  `CREATE INDEX ActedInByPerson ON ActedIn (personId)`,
  `CREATE INDEX ActedInByMovie ON ActedIn (movieId)`,
  `CREATE INDEX HasGenreByMovie ON HasGenre (movieId)`,
  `CREATE INDEX HasGenreByGenre ON HasGenre (genreId)`,

  `CREATE OR REPLACE PROPERTY GRAPH movieGraph
  NODE TABLES (
    Movies,
    People,
    Genres
  )
  EDGE TABLES (
    Directed
      SOURCE KEY (personId) REFERENCES People (id)
      DESTINATION KEY (movieId) REFERENCES Movies (id)
      LABEL Directed,
    ActedIn
      SOURCE KEY (personId) REFERENCES People (id)
      DESTINATION KEY (movieId) REFERENCES Movies (id)
      LABEL ActedIn,
    HasGenre
      SOURCE KEY (genreId) REFERENCES Genres (id)
      DESTINATION KEY (movieId) REFERENCES Movies (id)
  )`
];
