import Ogma from '@linkurious/ogma';
import { isGenre, isMovie, isPerson, NodeDataType } from './types';

const placeholder = document.createElement('span');
document.body.appendChild(placeholder);
placeholder.style.visibility = 'hidden';

// helper routine to get the icon HEX code
export function getIconCode(className: string) {
  placeholder.className = className;
  const code = getComputedStyle(placeholder, ':before').content;
  return code[1];
}

const font = 'IBM Plex Sans';
const HIGHLIGHTED_STYLE = {
  outerStroke: {
    color: '#de425b'
  },
  text: {
    backgroundColor: '#2d2e41',
    color: '#fff',
    margin: 6
  }
};

export function addStyles(ogma: Ogma<NodeDataType>) {
  ogma.styles.addNodeRule(isMovie, {
    color: '#FCBC05',
    text: {
      content: node => node.getData('title'),
      font,
      size: 16.5,
      style: 'bold',
      minVisibleSize: 0
    },
    radius: 8,
    icon: {
      content: getIconCode('icon-film'),
      font: 'Lucide',
      scale: 0.5,
      color: '#372b09'
    }
  });
  ogma.styles.addNodeRule(isPerson, {
    color: '#4386F3',
    text: {
      content: node => node.getData('name'),
      font,
      size: 11,
      minVisibleSize: 10
    },
    icon: {
      content: getIconCode('icon-circle-user-round'),
      font: 'Lucide',
      scale: 0.5,
      color: '#fff'
    }
  });
  ogma.styles.addNodeRule(isGenre, {
    color: '#7843F3',
    radius: 4,
    text: {
      content: node => node.getData('name'),
      font,
      size: 11,
      minVisibleSize: 10
    },
    icon: {
      content: getIconCode('icon-tag'),
      font: 'Lucide',
      scale: 0.5,
      color: '#fff'
    }
  });

  ogma.styles.setSelectedNodeAttributes(HIGHLIGHTED_STYLE);
  ogma.styles.setHoveredNodeAttributes(HIGHLIGHTED_STYLE);
}
