import { Node, RawEdge, RawNode } from '@linkurious/ogma';
import {
  ACTED_IN,
  DIRECTED,
  GENRE,
  HAS_GENRE,
  MOVIE,
  PERSON
} from './constants';

// Types for our data model
export interface MovieRow {
  Rank: number;
  Title: string;
  Genre: string;
  Description: string;
  Director: string;
  Actors: string;
  Year: number;
  'Runtime (Minutes)': number;
  Rating: number;
  Votes: number;
  'Revenue (Millions)': number | null;
}

export interface Movie {
  id: string;
  title: string;
  description: string;
  year: number;
  runtime: number;
  votes: number;
}

export interface Person {
  id: string;
  name: string;
}

export interface Genre {
  id: string;
  name: string;
}

export interface DirectedRelationship {
  id: string;
  personId: string;
  movieId: string;
}

export interface ActedInRelationship {
  id: string;
  personId: string;
  movieId: string;
}

export interface HasGenreRelationship {
  id: string;
  movieId: string;
  genreId: string;
}

export enum NodeType {
  Person = PERSON,
  Movie = MOVIE,
  Genre = GENRE
}

export enum EdgeType {
  Directed = DIRECTED,
  ActedIn = ACTED_IN,
  HasGenre = HAS_GENRE
}

export const isMovie = (node: Node): node is Node<MovieData> => {
  return node.getData('type') === MOVIE;
};

export const isPerson = (node: Node): node is Node<PersonData> => {
  return node.getData('type') === PERSON;
};

export const isGenre = (node: Node): node is Node<GenreData> => {
  return node.getData('type') === GENRE;
};

export type MovieData = Movie & { type: NodeType.Movie };
export type MovieNode = RawNode<MovieData>;
export type PersonData = Person & { type: NodeType.Person };
export type PersonNode = RawNode<PersonData>;
export type GenreData = Genre & { type: NodeType.Genre };
export type GenreNode = RawNode<GenreData>;
export type DirectedEdge = RawEdge<
  DirectedRelationship & { type: EdgeType.Directed }
>;
export type ActedInEdge = RawEdge<
  ActedInRelationship & { type: EdgeType.ActedIn }
>;
export type HasGenreEdge = RawEdge<
  HasGenreRelationship & { type: EdgeType.HasGenre }
>;

export type GraphNode = MovieNode | PersonNode | GenreNode;
export type GraphEdge = DirectedEdge | ActedInEdge | HasGenreEdge;

export type NodeDataType = PersonData | MovieData | GenreData;
export type EdgeDataType = DirectedEdge | ActedInEdge | HasGenreEdge;
